@@ -5,7 +5,10 @@ import sys
 from mock import patch
 
 from django.test import TestCase
-from django.utils import unittest
+try:
+    from django.utils import unittest
+except ImportError:
+    import unittest2 as unittest
 
 from pipeline.conf import settings
 from pipeline.compressors import Compressor
@@ -116,11 +119,10 @@ class CompressorTest(TestCase):
         self.assertEquals(asset_path, "/images/sprite.png")
 
     def test_url_rewrite(self):
-        self.maxDiff = None
         output = self.compressor.concatenate_and_rewrite([
             'css/urls.css',
         ])
-        self.assertMultiLineEqual("""@font-face {
+        self.assertEquals("""@font-face {
   font-family: 'Pipeline';
   src: url(http://localhost/static/fonts/pipeline.eot);
   src: url(http://localhost/static/fonts/pipeline.eot?#iefix) format('embedded-opentype');
